@@ -1,43 +1,36 @@
 import logging
 import os
+import shutil
 import pickle
 import sys
 from logging.handlers import RotatingFileHandler
 from pathlib import Path
-from typing import Optional
+
+from domains_api.constants import HOME_PATH_DIR_NAME
 
 
 class FileHandlers:
-    def __init__(self, path: Optional[str] = None, log_level: str = "info"):
+    def __init__(self, log_level: str = "info"):
         self.log_level = self.set_log_level(log_level)
-        self.path, self.op_sys = self.file_handling(path)
-        self.user_file = os.path.abspath(self.path / "domains.user")
-        self.log_file = str(os.path.abspath(self.path / "domains.log"))
-        if not os.path.exists(self.log_file) or not os.path.exists(self.user_file):
+        self.path = Path(os.path.abspath(os.path.dirname(__file__)))
+        self.user_file = self.path / "domains.user"
+        self.home_path = Path(os.getenv("HOME"))
+        self.log_path = self.home_path / HOME_PATH_DIR_NAME
+
+        if not os.path.exists(self.user_file):
+            self._migrate_old_versions()
+        if not os.path.exists(self.log_path):
             self.make_directories()
         self.sys_log = self.initialize_loggers()
 
-    @staticmethod
-    def file_handling(path: Optional[str] = None):
-        if os.name == "nt":
-            path = path or "domains"
-            path = Path(os.getenv("LOCALAPPDATA")) / path
-            op_sys = "nt"
-        else:
-            path = path or ".domains"
-            path = Path(os.path.abspath(os.getenv("HOME"))) / path
-            op_sys = "pos"
-        return path, op_sys
-
     def make_directories(self):
-        os.makedirs(self.path, exist_ok=True)
+        os.makedirs(self.log_path, exist_ok=True)
 
-    @staticmethod
-    def file_or_dir(path):
-        if os.path.isdir(path):
-            os.chmod(path, 0o770)
-        elif os.path.isfile(path):
-            os.chmod(path, 0o665)
+    def _migrate_old_versions(self):
+        self.make_directories()
+        os.system(f'mv {self.home_path / ".domains" / "domains.user"} {self.path}')
+        os.system(f'mv {self.home_path / ".domains" / "domains.log"} {self.log_path}')
+        shutil.rmtree(self.home_path / '.domains')
 
     def initialize_loggers(self):
         sys_log = logging.getLogger("Domains DDNS API")
@@ -49,7 +42,7 @@ class FileHandlers:
             level = logging.INFO
         sys_log.setLevel(level)
         fh = RotatingFileHandler(
-            self.log_file,
+            self.log_path / 'domains.log',
             mode="a",
             maxBytes=100 * 1024,
             backupCount=2,
@@ -86,19 +79,16 @@ class FileHandlers:
         return self.log_level
 
     def save_user(self, user):
-        """Pickle (serialize) user instance."""
         with open(self.user_file, "wb") as pickle_file:
             pickle.dump(user, pickle_file)
         self.log("User saved.", "debug")
 
     @staticmethod
     def load_user(user_file):
-        """Unpickle (deserialize) user instance."""
         with open(user_file, "rb") as pickle_file:
             return pickle.load(pickle_file)
 
     def delete_user(self):
-        """Delete user pickle file (serialized user instance)."""
         if (
             input("Are you sure you want to delete the current user? [Y/n] ").lower()
             == "n"
@@ -111,14 +101,6 @@ class FileHandlers:
             '"domains-api -l path/to/pickle" to load one from file'
         )
 
-    def clear_logs(self):
-        with open(self.log_file, "r") as r:
-            lines = r.readlines()
-            if len(lines) > 100:
-                tail = r.readlines()[-10:]
-                with open(self.log_file, "w") as w:
-                    w.writelines(tail)
-
 
 if __name__ == "__main__":
     fhs = FileHandlers()
